pub struct AseHelper;Trait Implementations
Sourceimpl Completer for AseHelper
impl Completer for AseHelper
Sourceimpl Highlighter for AseHelper
impl Highlighter for AseHelper
Sourcefn highlight<'l>(&self, line: &'l str, pos: usize) -> Cow<'l, str>
fn highlight<'l>(&self, line: &'l str, pos: usize) -> Cow<'l, str>
Takes the currently edited
line with the cursor position and
returns the highlighted version (with ANSI color). Read moreSourcefn highlight_prompt<'b, 's, 'p>(
&'s self,
prompt: &'p str,
default: bool,
) -> Cow<'b, str>where
's: 'b,
'p: 'b,
fn highlight_prompt<'b, 's, 'p>(
&'s self,
prompt: &'p str,
default: bool,
) -> Cow<'b, str>where
's: 'b,
'p: 'b,
Takes the
prompt and
returns the highlighted version (with ANSI color).Sourcefn highlight_hint<'h>(&self, hint: &'h str) -> Cow<'h, str>
fn highlight_hint<'h>(&self, hint: &'h str) -> Cow<'h, str>
Takes the
hint and
returns the highlighted version (with ANSI color).Sourcefn highlight_candidate<'c>(
&self,
candidate: &'c str,
completion: CompletionType,
) -> Cow<'c, str>
fn highlight_candidate<'c>( &self, candidate: &'c str, completion: CompletionType, ) -> Cow<'c, str>
Takes the completion
candidate and
returns the highlighted version (with ANSI color). Read moreSourceimpl Validator for AseHelper
impl Validator for AseHelper
Sourcefn validate(&self, _ctx: &mut ValidationContext<'_>) -> Result<ValidationResult>
fn validate(&self, _ctx: &mut ValidationContext<'_>) -> Result<ValidationResult>
Takes the currently edited
input and returns a
ValidationResult indicating whether it is valid or not along
with an option message to display about the result. The most
common validity check to implement is probably whether the
input is complete or not, for instance ensuring that all
delimiters are fully balanced. Read moreSourcefn validate_while_typing(&self) -> bool
fn validate_while_typing(&self) -> bool
Configure whether validation is performed while typing or only
when user presses the Enter key. Read more
impl Helper for AseHelper